@@ -94,7 +94,7 @@ typedef struct {
 	lht_node_t *src;
 } rnd_confprop_t;
 
-typedef struct {
+struct rnd_conf_native_s {
 	/* static fields defined by the macros */
 	const char *description;
 	const char *hash_path;     /* points to the hash key once its added in the hash (else: NULL) */
@@ -120,8 +120,7 @@ typedef struct {
 	vtp0_t hid_callbacks; /* vector of (const rnd_conf_hid_callbacks_t *) */
 
 	const char *gui_edit_act; /* if non-zero, run this action for GUI editing; args: role_name, full_list_conf_path, item_name */
-} rnd_conf_native_t;
-
+};
 
 struct conf_listitem_s {
 	rnd_conf_native_type_t type;
@@ -168,10 +167,11 @@ void rnd_conf_load_all(const char *project_fn, const char *design_fn);
    trigger a refresh */
 extern int rnd_conf_in_production;
 
-/* Load a file or a string as a role */
+/* Load a file or a string as a role
+   [3.2.0]: if fn is NULL, create an empty lihata document for the role */
 int rnd_conf_load_as(rnd_conf_role_t role, const char *fn, int fn_is_text);
 
-/* copy root to be the new config of role; root must be a li:pcb-rnd-conf-v1
+/* copy root to be the new config of role; root must be a li:APPNAME-conf-v1
    return 0 on success and removes/invalidates root */
 int rnd_conf_insert_tree_as(rnd_conf_role_t role, lht_node_t *root);
 
@@ -364,6 +364,8 @@ do { \
 lht_node_t *rnd_conf_lht_get_first(rnd_conf_role_t target, int create);
 lht_node_t *rnd_conf_lht_get_first_crpol(rnd_conf_role_t target, rnd_conf_policy_t pol, int create);
 
+/* [3.2.0] Get first config subtree for role, create the file if doesn't exist */
+lht_node_t *rnd_pref_ensure_conf_root(rnd_hidlib_t *hidlib, rnd_conf_role_t role);
 
 /* loop helper */
 rnd_conf_listitem_t *rnd_conf_list_first_str(rnd_conflist_t *list, const char **item_str, int *idx);
@@ -408,7 +410,10 @@ int rnd_conf_parse_text(rnd_confitem_t *dst, int idx, rnd_conf_native_type_t typ
 /* Returns the user configuration file name */
 const char *rnd_conf_get_user_conf_name();
 
-/* Determine the file name of the project file - project_fn and design_fn can be NULL */
+/* Determine the file name of the project file - project_fn and design_fn
+   can be NULL. Design_fn should be the "load name" of the file: if it is
+   a symlink, using the realname() would assume project file at symlink target
+   but project file should be next to the symlink. */
 const char *rnd_conf_get_project_conf_name(const char *project_fn, const char *design_fn, const char **out_project_fn);
 
 /* Get the first subtree that matches pol within target; allocate new
