@@ -36,6 +36,7 @@
  * For details of all supported specifiers, see the comment at the
  * top of rnd_printf.h */
 
+#include <stdio.h>
 #include <locale.h>
 #include <ctype.h>
 #include <math.h>
@@ -89,8 +90,7 @@ static inline void make_printf_spec(char *printf_spec_new, const char *printf_sp
 
 	*trunc0 = 0;
 
-	while (printf_spec[i] == '%' || isdigit(printf_spec[i]) ||
-				 printf_spec[i] == '-' || printf_spec[i] == '+' || printf_spec[i] == '#' || printf_spec[i] == '0')
+	while((printf_spec[i] == '%') || isdigit(printf_spec[i]) || (printf_spec[i] == '-') || (printf_spec[i] == '+') || (printf_spec[i] == '#') || (printf_spec[i] == '0'))
 		++i;
 
 	if (printf_spec[i] == '.') {
