@@ -6,7 +6,7 @@
 #include <librnd/core/hid_init.h>
 #include <librnd/core/hidlib_conf.h>
 
-#include <librnd/plugins/lib_hid_gl/draw_gl.h>
+#include <librnd/plugins/lib_hid_gl/hidgl.h>
 
 #include <librnd/plugins/lib_gtk2_common/compat.h>
 #include <librnd/plugins/lib_gtk_common/glue_common.h>
@@ -16,12 +16,13 @@ const char *ghid_gl_cookie = "gtk2 hid, gl";
 
 rnd_hid_t gtk2_gl_hid;
 
-extern void ghid_gl_install(rnd_gtk_impl_t *impl, rnd_hid_t *hid);
+extern int ghid_gl_install(rnd_gtk_impl_t *impl, rnd_hid_t *hid);
 
 int gtk2_gl_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 {
 	rnd_gtkg_glue_common_init(ghid_gl_cookie);
-	ghid_gl_install(&ghidgui->impl, hid);
+	if (ghid_gl_install(&ghidgui->impl, hid) != 0)
+		return -1;
 	return rnd_gtk_parse_arguments(hid, argc, argv);
 }
 
@@ -31,7 +32,7 @@ void pplg_uninit_hid_gtk2_gl(void)
 {
 	rnd_event_unbind_allcookie(ghid_gl_cookie);
 	rnd_conf_hid_unreg(ghid_gl_cookie);
-	drawgl_uninit();
+	hidgl_uninit();
 	rnd_gtkg_glue_common_uninit(ghid_gl_cookie);
 }
 
