@@ -1,5 +1,6 @@
 #include "xincludes.h"
 
+#include <genlist/gendlist.h>
 #include <librnd/rnd_config.h>
 #include <librnd/core/hidlib_conf.h>
 
@@ -21,6 +22,8 @@
 #include <librnd/core/hid_init.h>
 #include "ltf_stdarg.h"
 #include <librnd/core/misc_util.h>
+#include "dialogs.h"
+
 
 int rnd_ltf_ok;
 extern rnd_hidlib_t *ltf_hidlib;
@@ -162,25 +165,7 @@ int rnd_ltf_wait_for_dialog(Widget w)
 
 /* ------------------------------------------------------------ */
 
-typedef struct {
-	void *caller_data; /* WARNING: for now, this must be the first field (see core spinbox enter_cb) */
-	rnd_hidlib_t *hidlib; /* the hidlib that was active at the moment the dialog was created */
-	rnd_hid_attribute_t *attrs;
-	int n_attrs;
-	Widget *wl;   /* content widget */
-	Widget *wltop;/* the parent widget, which is different from wl if reparenting (extra boxes, e.g. for framing or scrolling) was needed */
-	Widget **btn; /* enum value buttons */
-	Widget dialog;
-	rnd_hid_attr_val_t property[RND_HATP_max];
-	Dimension minw, minh;
-	void (*close_cb)(void *caller_data, rnd_hid_attr_ev_t ev);
-	char *id;
-	unsigned close_cb_called:1;
-	unsigned already_closing:1;
-	unsigned inhibit_valchg:1;
-	unsigned widget_destroyed:1;
-	unsigned set_ok:1;
-} lesstif_attr_dlg_t;
+static gdl_list_t ltf_dad_dialogs; /* all open DAD dialogs */
 
 static void attribute_dialog_readres(lesstif_attr_dlg_t *ctx, int widx)
 {
@@ -692,6 +677,7 @@ void *lesstif_attr_dlg_new(rnd_hid_t *hid, const char *id, rnd_hid_attribute_t *
 	lesstif_attr_dlg_t *ctx;
 
 	ctx = calloc(sizeof(lesstif_attr_dlg_t), 1);
+	ctx->creating = 1;
 	ctx->hidlib = ltf_hidlib;
 	ctx->attrs = attrs;
 	ctx->n_attrs = n_attrs;
@@ -702,6 +688,8 @@ void *lesstif_attr_dlg_new(rnd_hid_t *hid, const char *id, rnd_hid_attribute_t *
 	ctx->widget_destroyed = 0;
 	ctx->id = rnd_strdup(id);
 
+	gdl_append(&ltf_dad_dialogs, ctx, link);
+
 	ctx->wl = (Widget *) calloc(n_attrs, sizeof(Widget));
 	ctx->wltop = (Widget *)calloc(n_attrs, sizeof(Widget));
 	ctx->btn = (Widget **) calloc(n_attrs, sizeof(Widget *));
@@ -759,6 +747,7 @@ void *lesstif_attr_dlg_new(rnd_hid_t *hid, const char *id, rnd_hid_attribute_t *
 
 	ltf_initial_wstates(ctx);
 
+	ctx->creating = 0;
 	return ctx;
 }
 
@@ -767,11 +756,14 @@ void *lesstif_attr_sub_new(Widget parent_box, rnd_hid_attribute_t *attrs, int n_
 	lesstif_attr_dlg_t *ctx;
 
 	ctx = calloc(sizeof(lesstif_attr_dlg_t), 1);
+	ctx->creating = 1;
 	ctx->hidlib = ltf_hidlib;
 	ctx->attrs = attrs;
 	ctx->n_attrs = n_attrs;
 	ctx->caller_data = caller_data;
 
+	gdl_append(&ltf_dad_dialogs, ctx, link);
+
 	ctx->wl = (Widget *) calloc(n_attrs, sizeof(Widget));
 	ctx->wltop = (Widget *)calloc(n_attrs, sizeof(Widget));
 	ctx->btn = (Widget **) calloc(n_attrs, sizeof(Widget *));
@@ -779,6 +771,7 @@ void *lesstif_attr_sub_new(Widget parent_box, rnd_hid_attribute_t *attrs, int n_
 	attribute_dialog_add(ctx, parent_box, 0);
 	ltf_initial_wstates(ctx);
 
+	ctx->creating = 0;
 	return ctx;
 }
 
@@ -801,8 +794,10 @@ void lesstif_attr_dlg_close(void *hid_ctx)
 
 	if (!ctx->widget_destroyed) {
 		ctx->widget_destroyed = 1;
-		XtDestroyWidget(ctx->dialog);
-		ltf_attr_destroy_cb(ctx->dialog, ctx, NULL);
+		if (ctx->dialog != NULL) {
+			XtDestroyWidget(ctx->dialog);
+			ltf_attr_destroy_cb(ctx->dialog, ctx, NULL);
+		}
 	}
 }
 
@@ -817,12 +812,26 @@ void lesstif_attr_dlg_free(void *hid_ctx)
 
 	lesstif_attr_dlg_close(ctx);
 
+	gdl_remove(&ltf_dad_dialogs, ctx, link);
+
 	free(ctx->wl);
 	free(ctx->wltop);
 	free(ctx->id);
 	free(ctx);
 }
 
+/* Close and free all open DAD dialogs */
+void lesstif_attr_dlg_free_all(void)
+{
+	lesstif_attr_dlg_t *curr, *next;
+
+	/* don't rely on closing always the first, just in case it fails to unlink */
+	for(curr = gdl_first(&ltf_dad_dialogs); curr != NULL; curr = next) {
+		next = curr->link.next;
+		lesstif_attr_dlg_free(curr);
+	}
+}
+
 void lesstif_attr_dlg_property(void *hid_ctx, rnd_hat_property_t prop, const rnd_hid_attr_val_t *val)
 {
 	lesstif_attr_dlg_t *ctx = hid_ctx;
@@ -945,7 +954,7 @@ TODO("layer: call a redraw on the edit group")
 
 rnd_hidlib_t *ltf_attr_get_dad_hidlib(void *hid_ctx)
 {
-	lesstif_attr_dlg_t * ctx = hid_ctx;
+	lesstif_attr_dlg_t *ctx = hid_ctx;
 	if (rnd_hid_enable_per_dialog_hidlib)
 		return ctx->hidlib;
 	return ltf_hidlib;
