@@ -70,8 +70,14 @@ static void maybe_scroll_to_bottom()
 
 static void irc_append(irc_ctx_t *ctx, const char *str, int may_hilight)
 {
-	rnd_hid_attribute_t *atxt = &ctx->dlg[ctx->wtxt];
-	rnd_hid_text_t *txt = atxt->wdata;
+	rnd_hid_attribute_t *atxt;
+	rnd_hid_text_t *txt;
+
+	if (ctx->dlg == NULL)
+		return;
+
+	atxt = &ctx->dlg[ctx->wtxt];
+	txt = atxt->wdata;
 
 	txt->hid_set_text(atxt, ctx->dlg_hid_ctx, RND_HID_TEXT_APPEND, str);
 
@@ -165,13 +171,13 @@ static void irc_disconnect(const char *reason)
 
 static void irc_connect(int open_dlg)
 {
-	if (uirc_connect(&irc_ctx.irc, irc_ctx.server, irc_ctx.port, "librnd irc action") == 0) {
-		if (open_dlg)
-			rnd_dlg_irc();
+	if (open_dlg)
+		rnd_dlg_irc();
+
+	if (uirc_connect(&irc_ctx.irc, irc_ctx.server, irc_ctx.port, "librnd irc action") == 0)
 		irc_printf(0, ("*** Connecting %s:%d... ***\n", irc_ctx.server, irc_ctx.port));
-	}
 	else
-		irc_printf(2, ("*** ERROR: failed to connect the server at %s:%p. ***\n", irc_ctx.server, irc_ctx.port));
+		irc_printf(2, ("*** ERROR: failed to connect the server at %s:%d. ***\n", irc_ctx.server, irc_ctx.port));
 }
 
 static void on_me_part(uirc_t *ctx, int query, char *chan)
