@@ -218,7 +218,7 @@ static gboolean tree_table_filter_visible_func(GtkTreeModel *model, GtkTreeIter
 /* Activation (e.g. double-clicking) of a footprint row. As a convenience
 to the user, GTK provides Shift-Arrow Left, Right to expand or
 contract any node with children. */
-static void tree_row_activated(GtkTreeView *tree_view, GtkTreePath *path, GtkTreeViewColumn *column, rnd_hid_attribute_t *attr, int call_changed)
+static void tree_row_activated(GtkTreeView *tree_view, GtkTreePath *path, GtkTreeViewColumn *column, rnd_hid_attribute_t *attr, int call_changed, int auto_exp)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
@@ -226,10 +226,12 @@ static void tree_row_activated(GtkTreeView *tree_view, GtkTreePath *path, GtkTre
 	model = gtk_tree_view_get_model(tree_view);
 	gtk_tree_model_get_iter(model, &iter, path);
 
-	if (gtk_tree_view_row_expanded(tree_view, path))
-		gtk_tree_view_collapse_row(tree_view, path);
-	else
-		gtk_tree_view_expand_row(tree_view, path, FALSE);
+	if (auto_exp) {
+		if (gtk_tree_view_row_expanded(tree_view, path))
+			gtk_tree_view_collapse_row(tree_view, path);
+		else
+			gtk_tree_view_expand_row(tree_view, path, FALSE);
+	}
 
 	if (call_changed) {
 		attr_dlg_t *ctx = g_object_get_data(G_OBJECT(tree_view), RND_OBJ_PROP);
@@ -321,7 +323,7 @@ static gboolean rnd_gtk_tree_table_key_press_cb(GtkWidget *wdg, long mods, long
 	if (enter_key || force_activate) {
 		path = gtk_tree_model_get_path(model, &iter);
 		if (path != NULL) {
-			tree_row_activated(tree_view, path, NULL, attr, !!enter_key);
+			tree_row_activated(tree_view, path, NULL, attr, !!enter_key, enter_key || !(attr->hatt_flags & RND_HATF_TREE_NO_AUTOEXP));
 		}
 		gtk_tree_path_free(path);
 	}
@@ -338,68 +340,6 @@ static gboolean rnd_gtk_tree_table_row_activated_cb(GtkTreeView *tv, GtkTreePath
 	return FALSE;
 }
 
-/* Return the x coord of the first non-arrow pixel or -1 if there's no arrow */
-static int rnd_gtk_tree_table_arrow_width(GtkTreeView *tv, GtkTreePath *tp)
-{
-	GdkRectangle rect;
-	GtkTreeViewColumn *col = gtk_tree_view_get_expander_column(tv);
-
-	if (col == NULL)
-		return -1;
-	gtk_tree_view_get_cell_area(tv, tp, col, &rect);
-
-	return rect.x;
-}
-
-#ifdef RND_FOR_GTK2
-/* Handle the double-click to be equivalent to "row-activated" signal */
-static gboolean rnd_gtk_tree_table_button_press_cb(GtkWidget *widget, GdkEvent *ev, rnd_hid_attribute_t *attr)
-{
-	GtkTreeView *tv = GTK_TREE_VIEW(widget);
-	GtkTreeModel *model;
-	GtkTreeIter iter;
-	GtkTreePath *path;
-
-	/*if (ev->button.type == GDK_2BUTTON_PRESS)*/ {
-		model = gtk_tree_view_get_model(tv);
-		gtk_tree_view_get_path_at_pos(tv, ev->button.x, ev->button.y, &path, NULL, NULL, NULL);
-		if (path != NULL) {
-			int minx = rnd_gtk_tree_table_arrow_width(tv, path);
-			if (ev->button.x < minx)
-				return FALSE; /* do not activate whenclicked on the arrow (interferes with gtk auto expand) */
-
-			gtk_tree_model_get_iter(model, &iter, path);
-			tree_row_activated(tv, path, NULL, attr, 0);
-		}
-	}
-
-	return FALSE;
-}
-
-static gboolean rnd_gtk_tree_table_button_release_cb(GtkWidget *widget, GdkEvent *ev, rnd_hid_attribute_t *attr)
-{
-	GtkTreeView *tv = GTK_TREE_VIEW(widget);
-	GtkTreeModel *model;
-	GtkTreeIter iter;
-	GtkTreePath *path;
-
-	model = gtk_tree_view_get_model(tv);
-	gtk_tree_view_get_path_at_pos(tv, ev->button.x, ev->button.y, &path, NULL, NULL, NULL);
-	if (path != NULL) {
-		int minx = rnd_gtk_tree_table_arrow_width(tv, path);
-		if (ev->button.x < minx)
-			return FALSE; /* do not activate whenclicked on the arrow (interferes with gtk auto expand) */
-
-		gtk_tree_model_get_iter(model, &iter, path);
-		/* Do not activate the row if LEFT-click on a "parent category" row. */
-		if (ev->button.button != 1 || !gtk_tree_model_iter_has_child(model, &iter))
-			tree_row_activated(tv, path, NULL, attr, 0);
-	}
-
-	return FALSE;
-}
-#endif
-
 static int rnd_gtk_tree_table_set(attr_dlg_t *ctx, int idx, const rnd_hid_attr_val_t *val)
 {
 	GtkWidget *tt = ctx->wl[idx];
@@ -411,7 +351,8 @@ static int rnd_gtk_tree_table_set(attr_dlg_t *ctx, int idx, const rnd_hid_attr_v
 	const char *s = val->str;
 
 	if ((s == NULL) || (*s == '\0')) {
-TODO("DAD: remove cursor - is it possible with gtk?")
+		GtkTreeSelection *sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(tt));
+		gtk_tree_selection_unselect_all(sel);
 		return 0;
 	}
 
@@ -530,12 +471,7 @@ static GtkWidget *rnd_gtk_tree_table_create(attr_dlg_t *ctx, rnd_hid_attribute_t
 	g_object_unref(model); /* destroy model automatically with view */
 	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(view)), GTK_SELECTION_NONE);
 
-#ifdef RND_FOR_GTK2
-	/* these are workarounds for gtk2, other versions won't need these */
-	g_object_set(view, "rules-hint", TRUE, "headers-visible", (tree->hdr != NULL), NULL);
-	g_signal_connect(G_OBJECT(view), "button-press-event", G_CALLBACK(rnd_gtk_tree_table_button_press_cb), attr);
-	g_signal_connect(G_OBJECT(view), "button-release-event", G_CALLBACK(rnd_gtk_tree_table_button_release_cb), attr);
-#endif
+	gtkc_tree_workarounds(view, attr, tree);
 
 	g_signal_connect(G_OBJECT(view), "cursor-changed", G_CALLBACK(rnd_gtk_tree_table_cursor), attr);
 	g_signal_connect(G_OBJECT(view), "row-activated", G_CALLBACK(rnd_gtk_tree_table_row_activated_cb), attr);
@@ -544,7 +480,7 @@ static GtkWidget *rnd_gtk_tree_table_create(attr_dlg_t *ctx, rnd_hid_attribute_t
 	gtk_tree_selection_set_mode(selection, GTK_SELECTION_SINGLE);
 
 	gtk_widget_set_tooltip_text(view, attr->help_text);
-	frame_scroll_(parent, attr->rnd_hatt_flags, &ctx->wltop[j], view);
+	frame_scroll_(parent, attr->rnd_hatt_flags, &ctx->wltop[j], view, 1);
 	g_object_set_data(G_OBJECT(view), RND_OBJ_PROP, ctx);
 
 	{
@@ -567,6 +503,7 @@ static void rnd_gtk_tree_pre_free(attr_dlg_t *ctx, rnd_hid_attribute_t *attr, in
 
 	/* make sure the model filter functions are not called back in an async call
 	   when we already free'd attr */
+	ctx->inhibit_valchg = 1; /* do not trigger user code cursor set callback */
 	gtk_tree_view_set_model(GTK_TREE_VIEW(tt), NULL);
 }
 
