@@ -237,6 +237,9 @@ static gint delete_chart_cb(GtkWidget *widget, long x, long y, long z, void *dat
 {
 	rnd_gtk_t *gctx = data;
 
+	/* do not call rnd_gtk_attr_dlg_free_all(gctx) here because Quit may cancel
+	   and keep the app running */
+
 	rnd_action(gctx->hidlib, "Quit");
 
 	/* Return TRUE to keep our app running.  A FALSE here would let the
@@ -247,6 +250,7 @@ static gint delete_chart_cb(GtkWidget *widget, long x, long y, long z, void *dat
 static gint destroy_chart_cb(GtkWidget *widget, long x, long y, long z, void *data)
 {
 	rnd_gtk_t *ctx = data;
+
 	ctx->impl.shutdown_renderer(ctx->impl.gport);
 	gtkc_main_quit();
 	return FALSE;
