@@ -172,6 +172,8 @@ static void rnd_gtkg_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options);
 
 static void rnd_gtkg_do_exit_(rnd_gtk_t *gctx)
 {
+	rnd_gtk_attr_dlg_free_all(gctx);
+
 	/* Need to force-close the command entry first because it has its own main
 	   loop that'd block the exit until the user closes the entry */
 	rnd_gtk_cmd_close(&gctx->topwin.cmd);
@@ -332,6 +334,7 @@ static int rnd_gtkg_usage(rnd_hid_t *hid, const char *topic)
 	fprintf(stderr, "\nInvocation:\n");
 	fprintf(stderr, "  %s --gui gtk2_gdk [options]\n", rnd_app.package);
 	fprintf(stderr, "  %s --gui gtk2_gl [options]\n", rnd_app.package);
+	fprintf(stderr, "  %s --gui gtk4_gl [options]\n", rnd_app.package);
 	fprintf(stderr, "  (depending on which gtk plugin(s) are compiled and installed)\n");
 	return 0;
 }
