@@ -218,6 +218,7 @@ static void script_dlg_open(void)
 	RND_DAD_COMPFLAG(script_dlg.dlg, RND_HATF_EXPFILL);
 	RND_DAD_BEGIN_HPANE(script_dlg.dlg);
 		RND_DAD_COMPFLAG(script_dlg.dlg, RND_HATF_EXPFILL);
+		RND_DAD_SET_PANE_NAME(script_dlg.dlg, "left-right");
 		/* left side */
 		RND_DAD_BEGIN_VBOX(script_dlg.dlg);
 			RND_DAD_COMPFLAG(script_dlg.dlg, RND_HATF_EXPFILL);
@@ -254,7 +255,7 @@ static void script_dlg_open(void)
 	/* set up the context */
 	script_dlg.active = 1;
 
-	RND_DAD_NEW("scripts", script_dlg.dlg, "pcb-rnd Scripts", &script_dlg, rnd_false, script_dlg_close_cb);
+	RND_DAD_NEW("scripts", script_dlg.dlg, "librnd Scripts", &script_dlg, rnd_false, script_dlg_close_cb);
 	script_dlg_s2d(&script_dlg);
 }
 
@@ -372,7 +373,7 @@ static const char rnd_acts_Oneliner[] = "Oneliner(lang, script)";
 /* DOC: onliner.html */
 static fgw_error_t rnd_act_Oneliner(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
-	const char *first = NULL, *lang = argv[0].val.func->name, *scr = NULL;
+	const char *first = NULL, *lang = argv[0].val.func->name, *olang, *scr = NULL;
 
 	if (strcmp(lang, "oneliner") == 0) {
 		/* call to oneliner(lang, script) */
@@ -400,8 +401,15 @@ static fgw_error_t rnd_act_Oneliner(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		}
 	}
 
+	olang = lang;
 	lang = rnd_script_guess_lang(NULL, lang, 0);
 
+	if (lang == NULL) {
+		rnd_message(RND_MSG_ERROR, "Failed to load scripting engine for %s\n", olang);
+		RND_ACT_IRES(-1);
+		return 0;
+	}
+
 	if (scr == NULL) {
 		RND_ACT_IRES(rnd_cli_enter(lang, lang));
 		return 0;
